@@ -82,15 +82,13 @@ prep() {
   (cd ${topdir} && \
   tar xv${opt_decomp}f ${src_orig_pkg} ; \
   cd ${topdir} && \
-  patch -p0 < ${src_patch} 
+  patch -p0 < ${src_patch} \
   && mkdirs )
 }
 conf() {
   (cd ${objdir} && \
-  lndir ${srcdir} && \
-  rm -rf .build .inst .sinst && \
   CFLAGS="${MY_CFLAGS}" LDFLAGS="${MY_LDFLAGS}" \
-  ./configure \
+  ${srcdir}/configure \
   --srcdir=${srcdir} --prefix=${prefix} \
   --exec-prefix=${prefix} --sysconfdir=${sysconfdir} \
   --libdir=${prefix}/lib --includedir=${prefix}/include \
