@@ -48,16 +48,17 @@
 #include <stdio.h>
 #include <string.h>
 #include "fcint.h"
-#include <freetype/freetype.h>
-#include <freetype/internal/ftobjs.h>
-#include <freetype/tttables.h>
-#include <freetype/ftsnames.h>
-#include <freetype/ttnameid.h>
-#include <freetype/t1tables.h>
+#include <ft2build.h>
+#include FT_FREETYPE_H
+#include FT_INTERNAL_OBJECTS_H
+#include FT_TRUETYPE_TABLES_H
+#include FT_SFNT_NAMES_H
+#include FT_TRUETYPE_IDS_H
+#include FT_TYPE1_TABLES_H
 
 #if (FREETYPE_MINOR > 1 || (FREETYPE_MINOR == 1 && FREETYPE_PATCH >= 4))
-#include <freetype/ftbdf.h>
-#include <freetype/ftmodule.h>
+#include FT_BDF_H
+#include FT_MODULE_H
 #define USE_FTBDF
 #define HAS_BDF_PROPERTY(f) ((f) && (f)->driver && \
 			     (f)->driver->root.clazz->get_interface)
@@ -156,7 +157,7 @@ static const struct {
 } FcNoticeFoundries[] = {
     { (const FcChar8*) "Bigelow",	(const FcChar8 *) "b&h" },
     { (const FcChar8*) "Adobe",		(const FcChar8 *) "adobe" },
-    { (const FcChar8*) "Bitstream",	(const FcChar8 *) "bitsteam" },
+    { (const FcChar8*) "Bitstream",	(const FcChar8 *) "bitstream" },
     { (const FcChar8*) "Monotype",	(const FcChar8 *) "monotype" },
     { (const FcChar8*) "Linotype",	(const FcChar8 *) "linotype" },
     { (const FcChar8*) "LINOTYPE-HELL", (const FcChar8 *) "linotype" },
@@ -769,10 +770,16 @@ FcFreeTypeQuery (const FcChar8	*file,
 		}
 	}
      
+#if 0
+	/* 
+	 * Don't bother with italic_angle; FreeType already extracts that
+	 * information for us and sticks it into style_flags
+	 */
         if (psfontinfo.italic_angle < 0) 
             slant = FC_SLANT_ITALIC; 
         else if (psfontinfo.italic_angle >= 0) 
             slant = FC_SLANT_ROMAN; 
+#endif
 
         if(!foundry)
             foundry = FcNoticeFoundry(psfontinfo.notice);
